Aglyph 2.1.0 testing summary — Aglyph 3.0.0 documentation

# Aglyph 2.1.0 testing summary

Warning

Changed in version 2.1.0.

The Python 2.6 lifespan has ended; the Aglyph test suite is no longer executed under this version.

Note

Prior to each Aglyph release being committed, tagged, and packaged, its test suite is executed on several Python implementations, versions, and platforms.

When a Python version reaches end-of-life, the Aglyph test suite is no longer “officially” executed against that version. This does not necessarily imply that Aglyph unit tests fail under that Python version; it simply means that I no longer publish or withhold a release based on the test suite results from that particular Python version.

## CPython

Version | Platform
--- | ---
2.7.6 | Linux-3.11.10-25-desktop-x86_64-with-SuSE-13.1-x86_64 GCC
2.7.9 | Darwin-14.0.0-x86_64-i386-64bit GCC 4.2.1 Compatible Apple LLVM 6.0 (clang-600.0.56)
| Windows-7-6.1.7601-SP1 MSC v.1500 32 bit (Intel)
3.1.4 | Windows-7-6.1.7601-SP1 MSC v.1500 32 bit (Intel)
3.1.5 | Darwin-14.0.0-x86_64-i386-64bit GCC 4.2.1 Compatible Apple LLVM 6.0 (clang-600.0.54)
3.2.5 | Windows-7-6.1.7601-SP1 MSC v.1500 32 bit (Intel)
3.2.6 | Darwin-14.0.0-x86_64-i386-64bit GCC 4.2.1 Compatible Apple LLVM 6.0 (clang-600.0.54)
3.3.5 | Linux-3.11.10-25-desktop-x86_64-with-SuSE-13.1-x86_64 GCC
| Windows-7-6.1.7601-SP1 MSC v.1600 32 bit (Intel)
3.3.6 | Darwin-14.0.0-x86_64-i386-64bit GCC 4.2.1 Compatible Apple LLVM 6.0 (clang-600.0.54)
3.4.2 | Darwin-14.0.0-x86_64-i386-64bit GCC 4.2.1 Compatible Apple LLVM 6.0 (clang-600.0.54)
| Windows-7-6.1.7601-SP1 MSC v.1600 32 bit (Intel)

## PyPy

Version | Platform
--- | ---
2.4.0 (CPython 2.7.8) | Darwin-14.0.0-x86_64-i386-64bit
| Linux-3.11.10-25-desktop-x86_64-with-SuSE-13.1-x86_64 GCC
| Windows-7-6.1.7601-SP1
2.4.0 (CPython 3.2.5) | Linux-3.11.10-25-desktop-x86_64-with-SuSE-13.1-x86_64 GCC
| Windows-7-6.1.7601-SP1

## Stackless Python

Version | Platform
--- | ---
3.1b3 060516 (CPython 2.7.8) | (v2.7.8-slp:ff29dd4f67de, Jan 8 2015, 23:41:02) Darwin-14.0.0-x86_64-i386-64bit
| (default, Jul 11 2014, 19:43:19) [MSC v.1500 32 bit (Intel)] Windows-7-6.1.7601-SP1
3.1b3 060516 (CPython 3.3.5) | (v3.3.5-slp:c856cc204b1c, Jan 9 2015, 00:11:34) Darwin-14.0.0-x86_64-i386-64bit
| (3.3-slp:cea13d5e707f+, Apr 10 2014, 10:33:27) [MSC v.1600 32 bit (Intel)] Windows-7-6.1.7601-SP1

## IronPython

Version | Platform
--- | ---
2.7.5 | Windows-7-6.1.7601-SP1 cli-32bit .NET 4.0.30319.18408 (32-bit)

## Jython

Version | Platform
--- | ---
2.5.3 | Java-1.8.0_05-Java_HotSpot-TM-_64-Bit_Server_VM,_25.5-b02,_Oracle_Corporation-on-Mac_OS_X-10.10.1-x86_64 Java HotSpot(TM) 64-Bit Server VM (Oracle Corporation)
| Java-1.7.0_55-OpenJDK_64-Bit_Server_VM,_24.55-b03,_Oracle_Corporation-on-Linux-3.11.10-25-desktop-amd64 OpenJDK 64-Bit Server VM (Oracle Corporation)
| Java-1.8.0_25-Java_HotSpot-TM-_Client_VM,_25.25-b02,_Oracle_Corporation-on-Windows_7-6.1-x86 Java HotSpot(TM) Client VM (Oracle Corporation)
2.7.0 | Java-1.8.0_05-Java_HotSpot-TM-_64-Bit_Server_VM,_25.5-b02,_Oracle_Corporation-on-Mac_OS_X-10.10.1-x86_64 java1.8.0_05
| Java-1.7.0_55-OpenJDK_64-Bit_Server_VM,_24.55-b03,_Oracle_Corporation-on-Linux-3.11.10-25-desktop-amd64 java1.7.0_55
| Java-1.8.0_25-Java_HotSpot-TM-_Client_VM,_25.25-b02,_Oracle_Corporation-on-Windows_7-6.1-x86 java1.8.0_25